#
# spec file for package python-jaraco.develop
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jaraco.develop
Version:        8.17.6
Release:        1.1
Summary:        Development utilities by jaraco
License:        MIT
URL:            https://github.com/jaraco/jaraco.develop
Source:         https://files.pythonhosted.org/packages/source/j/jaraco.develop/jaraco_develop-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module autocommand}
BuildRequires:  %{python_module PyNaCl}
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module ini2toml}
BuildRequires:  %{python_module jaraco.collections}
BuildRequires:  %{python_module jaraco.context}
BuildRequires:  %{python_module jaraco.packaging}
BuildRequires:  %{python_module jaraco.ui}
BuildRequires:  %{python_module jaraco.vcs >= 1.1}
BuildRequires:  %{python_module keyring}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module path}
BuildRequires:  %{python_module pytest >= 6}
BuildRequires:  %{python_module pytest-home}
BuildRequires:  %{python_module requests-file}
BuildRequires:  %{python_module requests-toolbelt}
BuildRequires:  %{python_module subprocess-tee}
BuildRequires:  git
# /SECTION
BuildRequires:  fdupes
Requires:       python-PyNaCl
Requires:       python-build
Requires:       python-ini2toml
Requires:       python-jaraco.context
Requires:       python-jaraco.ui
Requires:       python-jaraco.vcs >= 1.1
Requires:       python-keyring
Requires:       python-keyring
Requires:       python-packaging
Requires:       python-path
Requires:       python-requests
Requires:       python-requests-file
Requires:       python-requests-toolbelt
Requires:       python-setuptools
Requires:       python-subprocess-tee
Requires:       python-typer
Requires:       python-typing-extensions
BuildArch:      noarch
%python_subpackages

%description
Development utilities by jaraco

%prep
%autosetup -p1 -n jaraco_develop-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# *-github*.py and towncrier.get_version: No source repo or suitable VCS version found
# git.resolve: needs internet
# git.URLScheme: needs pytest plugin we don't have yet
%pytest --ignore-glob "*-github-*.py" -k "not (URLScheme or resolve or towncrier.get_version or target_for_root)"

%files %{python_files}
%doc NEWS.rst README.rst
%license LICENSE
%{python_sitelib}/jaraco/develop
%{python_sitelib}/jaraco[_.]develop-%{version}.dist-info

%changelog
* Fri Jul 18 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- update 8.17.6
  * Fix Windows handling in target_for_root. (#28)
  * Prefer glob for finding files in a possibly-non-existent directory. (#26)
  * Add support for adding secrets in coherent projects.
  * Fix issue in create-github-release with typer usage. (#23)
  * Add type annotations for base, branch, dry_run, and restore short options to tag and keyword.
  * Migrated from autocommand to typer for CLI handling. (#21)
  * Add support for resolving metadata even when pyproject.toml is in conflict. (#19)
  * When configuring a fork, configure the default repo as the upstream repo (for PRs, etc).
  * Rely on jaraco.packaging.metadata.hunt_down_url to resolve the homepage.
  * Fix bug where migrate-config would fail to include a homepage.
  * Inject the URLs agead of project.optional-dependencies, but only if there's not already a homepage indicated.
  * Fix bug where migrate-config would replace an already multiline contributor with extra space.
  * Add command for migrating config to pyproject.toml.
  * Succeed even if git returns no substitutions.
  * Restore Python 3.8 compatibility.
  * Fix late-add bug in add-project where item was chosen and not attribute.
  * Add routine to add a project.
  * In projects-run, flush stdout.
  * In projects-run, implemented selection and exclusion logic for tags and keywords.
  * Updated Python build routine for macOS to support OpenSSL 3. (#16)
  * Added support for file:// URL for projects list.
- update requirements from pyproject.toml
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make it compatible with older setuptools
* Wed Mar 26 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 8.6.0:
  * Features - In merge, ensure that an uncommented RTD badge
    isn't lost when resolving placeholders.
* Wed Jan  3 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Dec 19 2023 Dirk Müller <dmueller@suse.com>
- update to 8.5.0:
  * Update merge resolver to re-substitute placeholders to honor
    upstream changes.
  * Add 'projects-run' script for running a command across all of
    the projects.
  * Adding script for syncing a backport (configparser,
    singledispatch) to a CPython branch.
* Thu Aug 17 2023 Markéta Machová <mmachova@suse.com>
- Initial packaging (v8.2.0), needed by setuptools:test
